@@ -1,6 +1,7 @@
 from . import DeploymentsClient, ExperimentsClient, HyperparameterJobsClient, ModelsClient, ProjectsClient, \
     MachinesClient, NotebooksClient, SecretsClient
 from .job_client import JobsClient
+from .workflow_client import WorkflowsClient
 from .. import logger as sdk_logger
 
 
@@ -19,3 +20,4 @@ class SdkClient(object):
         self.machines = MachinesClient(api_key=api_key, logger=logger)
         self.notebooks = NotebooksClient(api_key=api_key, logger=logger)
         self.secrets = SecretsClient(api_key=api_key, logger=logger)
+        self.workflows = WorkflowsClient(api_key=api_key, logger=logger)
